# Table of Contents

- [technology-obsolescence-risk-statuses-and-views-in-reports](<./technology-obsolescence-risk-statuses-and-views-in-reports.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Technology Obsolescence Risk Statuses and Views in Reports](<./Technology-Obsolescence-Risk-Statuses-and-Views-in-Reports.md>)
  - [Obsolescence Risk Statuses of IT Components](<./Technology-Obsolescence-Risk-Statuses-and-Views-in-Reports/Obsolescence-Risk-Statuses-of-IT-Components.md>)
  - [Obsolescence Risk View Aggregation at the Application Level](<./Technology-Obsolescence-Risk-Statuses-and-Views-in-Reports/Obsolescence-Risk-View-Aggregation-at-the-Application-Level.md>)
  - [Obsolescence Risk Views](<./Technology-Obsolescence-Risk-Statuses-and-Views-in-Reports/Obsolescence-Risk-Views.md>)
  - [Missing Data Percentage](<./Technology-Obsolescence-Risk-Statuses-and-Views-in-Reports/Missing-Data-Percentage.md>)
  - [Mitigated Risk Percentage](<./Technology-Obsolescence-Risk-Statuses-and-Views-in-Reports/Mitigated-Risk-Percentage.md>)
  - [Unaddressed Risk Percentage](<./Technology-Obsolescence-Risk-Statuses-and-Views-in-Reports/Unaddressed-Risk-Percentage.md>)
